@@ -28,6 +28,14 @@ _PATH_ARGUMENT = click.Argument(
 """click.Option: An general paths argument."""
 
 
+_VERBOSE_OPTION = click.Option(
+    ["-v", "--verbose"],
+    type=int,
+    default=None,
+    help="Make pytask verbose (>= 0) or quiet (< 0) [default: 0]",
+)
+
+
 @hookimpl(trylast=True)
 def pytask_extend_command_line_interface(cli):
     """Register general markers."""
@@ -37,3 +45,5 @@ def pytask_extend_command_line_interface(cli):
         cli.commands[command].params.append(_IGNORE_OPTION)
     for command in ["build", "clean", "collect", "dag", "profile"]:
         cli.commands[command].params.append(_PATH_ARGUMENT)
+    for command in ["build"]:
+        cli.commands[command].params.append(_VERBOSE_OPTION)
